#
# spec file for package ghc-mustache
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name mustache
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.4.1
Release:        bp155.1.6
Summary:        A mustache template parser library
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cmdargs-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-th-lift-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-yaml-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-base-unicode-symbols-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-lens-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-tar-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-wreq-devel
BuildRequires:  ghc-zlib-devel
%endif

%description
Allows parsing and rendering template files with mustache markup. See the
mustache <http://mustache.github.io/mustache.5.html language reference>.

Implements the mustache spec version 1.1.3.

/Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/haskell-mustache

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Wed Mar 23 2022 Peter Simons <psimons@suse.com>
- Update mustache to version 2.4.1.
  [#]# v2.4.1
  - Compatibility with `containers >= 0.2.17`
* Tue Mar  8 2022 Peter Simons <psimons@suse.com>
- Update mustache to version 2.4.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Jan 30 2022 Peter Simons <psimons@suse.com>
- Update mustache to version 2.4.0.
  [#]# v2.4.0
  - Support for aeson 2
  [#]# v2.3.2
  - Added support for GHC 9.0.1
* Tue Oct 12 2021 psimons@suse.com
- Update mustache to version 2.3.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Thu Sep 17 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with min 4GB disk space for ppc64/ppc64le
* Fri Sep  4 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Thu Dec 19 2019 psimons@suse.com
- Update mustache to version 2.3.1.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update mustache to version 2.3.0.
  - Changed `EitherT` to `ExceptT` (deprecation)
  - removed `getFile` from public API
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 2.2.3.
* Thu May 18 2017 psimons@suse.com
- Update to version 2.1.4 with cabal2obs.
* Tue Apr  4 2017 psimons@suse.com
- Update to version 2.1.3 with cabal2obs.
* Mon Nov 14 2016 psimons@suse.com
- Update to version 2.1.2 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 2.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.0.2 revision 0 with cabal2obs.
